<template>
  <div class="app-container">
    <el-form
      :model="queryParams"
      ref="queryForm"
      size="small"
      :inline="true"
      v-show="showSearch"
      label-width="68px"
      @submit.native.prevent
    >
      <el-form-item label="码头名称" prop="NAME">
        <el-input
          v-model="queryParams.name"
          placeholder="请输入码头名称"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery"
          >搜索</el-button
        >
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['system:wharf:add']"
          >新增</el-button
        >
      </el-col>
      <!-- <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['system:wharf:edit']"
        >修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['system:wharf:remove']"
        >删除</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
          @click="handleExport"
          v-hasPermi="['system:wharf:export']"
        >导出</el-button>
      </el-col> -->
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table
      v-loading="loading"
      :data="wharfList"
      @selection-change="handleSelectionChange"
    >
      <!-- <el-table-column type="selection" width="55" align="center" /> -->
      <el-table-column label="id" align="center" prop="whId" />
      <el-table-column label="码头名称" align="center" prop="name" />
      <el-table-column label="height" align="center" prop="height" />
      <el-table-column label="heading" align="center" prop="heading" />
      <el-table-column label="pitch" align="center" prop="pitch" />
      <el-table-column label="roll" align="center" prop="roll" />
      <el-table-column label="纬度" align="center" prop="latitude" />
      <el-table-column label="经度" align="center" prop="longitude" />
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['system:wharf:edit']"
            >修改</el-button
          >
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['system:wharf:remove']"
            >删除</el-button
          >
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total > 0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改码头对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="码头名称" prop="name">
          <el-input v-model="form.name" placeholder="请输入码头名称" />
        </el-form-item>
        <el-form-item label="height" prop="height">
          <el-input v-model="form.height" placeholder="请输入height" />
        </el-form-item>
        <el-form-item label="heading" prop="heading">
          <el-input v-model="form.heading" placeholder="请输入heading" />
        </el-form-item>
        <el-form-item label="pitch" prop="pitch">
          <el-input v-model="form.pitch" placeholder="请输入pitch" />
        </el-form-item>
        <el-form-item label="roll" prop="roll">
          <el-input v-model="form.roll" placeholder="请输入roll" />
        </el-form-item>
        <el-form-item label="纬度" prop="latitude">
          <el-input v-model="form.latitude" placeholder="请输入纬度" />
        </el-form-item>
        <el-form-item label="经度" prop="longitude">
          <el-input v-model="form.longitude" placeholder="请输入经度" />
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { listWharf, getWharf, delWharf, addWharf, updateWharf } from "@/api/manage/wharf";
import { beList } from "@/api/manage/berth";
export default {
  name: "Wharf",
  data() {
    return {
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 码头表格数据
      wharfList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        NAME: null,
        HEIGHT: null,
        HEADING: null,
        PITCH: null,
        LATITUDE: null,
        LONGITUDE: null,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {},
    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询码头列表 */
    getList() {
      this.loading = true;
      listWharf(this.queryParams).then((response) => {
        this.wharfList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        whId: null,
        NAME: null,
        HEIGHT: null,
        HEADING: null,
        PITCH: null,
        LATITUDE: null,
        LONGITUDE: null,
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map((item) => item.whId);
      this.single = selection.length !== 1;
      this.multiple = !selection.length;
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加码头";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const whId = row.whId || this.ids;
      getWharf(whId).then((response) => {
        this.form = response.data;
        this.open = true;
        this.title = "修改码头";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate((valid) => {
        if (valid) {
          if (this.form.whId != null) {
            updateWharf(this.form).then((response) => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addWharf(this.form).then((response) => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const whIds = row.whId;
      beList(whIds).then((response) => {
        if (response.data.length > 0) {
          this.$message.error(row.name + "下有泊位，请先删除对应泊位");
        } else {
          this.$modal
            .confirm('是否确认删除码头编号为"' + whIds + '"的数据项？')
            .then(function () {
              return delWharf(whIds);
            })
            .then(() => {
              this.getList();
              this.$modal.msgSuccess("删除成功");
            })
            .catch(() => {});
        }
      });
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download(
        "system/wharf/export",
        {
          ...this.queryParams,
        },
        `wharf_${new Date().getTime()}.xlsx`
      );
    },
  },
};
</script>
